# Rust API - User Registration and Email Verification

In this article, we will explore the process of building a REST API in Rust with features like user registration, email verification, login, and logout capabilities. Our API will be powered by the high-performance Axum framework and will utilize the SQLx toolkit to store data in a SQLite database. It's worth noting that while we use SQLite in this tutorial, you can easily adapt the code to work with other databases supported by SQLx.

![Rust API - User Registration and Email Verification](https://codevoweb.com/wp-content/uploads/2023/07/Rust-API-User-Registration-and-Email-Verification.webp)

## Topics Covered

- Running the Rust API on Your Machine
- Running the Rust API with a Frontend Application
- Setting up the Rust Project
- Creating the HTML Email Templates
    - Creating the Base Layout
    - Creating the CSS Styles
    - Creating the Email Verification Template
- Handling Database Migrations
    - Starting with the Initial Migrations
    - Adding More Fields
- Creating the Database and Request Models
- Utility Functions for Sending the Emails
    - Getting Your SMTP Provider Credentials
    - Loading the Environment Variables
    - Creating a Struct with Methods for Sending the Emails
- Creating the API Response Models
- Creating the JWT Middleware Guard
- Creating the API Endpoint Handlers
    - Health Checker Handler
    - Register User with Email Verification Handler
    - Login User Handler
    - Verify Email Verification Token Handler
    - Logout User Handler
    - Retrieve Authentication User Credentials Handler
    - The Complete Code of the API Endpoint Handlers
- Creating the API Endpoints
- Registering the API Router
- Conclusion


Read the entire article here: [https://codevoweb.com/rust-api-user-registration-and-email-verification/](https://codevoweb.com/rust-api-user-registration-and-email-verification/)
